@@ -314,7 +314,8 @@ def flatten_invoice(invoice, validation):
                 )
             elif isinstance(v, list):
                 for counter, list_item in enumerate(v):
-                    if k != "terms":
+                    # TODO: fix terms and ibanAll
+                    if k != "terms" and k != "ibanAll":
                         temp_dict = {}
                         for item, value in list_item.items():
                             temp_dict[f"{k}_{item}_{counter}"] = value
