@@ -3,15 +3,17 @@ import xmltodict
 from ..services.requests import extract_invoice, validate_vat, validation
 from .commons import read_pdf
 
+AMOUNT_FIELDS = ("amount", "net", "due", "gross")
+
 
 def convert_to_xml(
     path,
     output_path,
     extractor_endpoint,
-    tax_rate_as_percentage=False,
     vat_validator_endpoint=None,
     validation_endpoint=None,
     token=None,
+    tax_rate_as_percentage=True,
 ):
     result = {}
     _, pdf = read_pdf(path)
@@ -40,11 +42,15 @@ def convert_to_xml(
     # One of the dirties hack I've ever done, here. I'm sorry
     if tax_rate_as_percentage:
         try:
-            for tax_line in result["invoiceExtractor"]["entities"]["totals"]["tax"]:
-                tax_line["rate"]["#text"] = str(
-                    round(float(tax_line["rate"]["#text"]) * 100, ndigits=2)
+            for tax_line in result["invoiceExtractor"]["entities"]["totals"]["taxes"][
+                "tax"
+            ]:
+                tax_line["rate"]["#text"] = format(
+                    round(float(tax_line["rate"]["#text"]) * 100, ndigits=2), ".2f"
                 )
-        except (KeyError, TypeError):
+                if tax_line["rate"]["#text"].endswith(".00"):
+                    tax_line["rate"]["#text"] = tax_line["rate"]["#text"][:-3]
+        except (KeyError, TypeError, ValueError):
             # guarding against the structure invoiceExtractor.entities.totals.tax
             # not being respected or whatever is there not being a list of objects
             # with a rate in it; failing silently if that's the case
@@ -128,7 +134,9 @@ def merge_validation(result):
                     "@risk": create_risk(entity, validation[entity])
                     if entity_got_validation
                     else "low",
-                    "#text": str(value),
+                    "#text": "{:.2f}".format(value)
+                    if entity in AMOUNT_FIELDS
+                    else str(value),
                 }
 
     if "validation" in result:
